==> supper_app-0.0.6.tar.gz: lib/src/module_management.dart <==
import 'dart:html';

import 'package:alice/alice.dart';
import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:supper_app/src/services/app_service/app_service.dart';
import 'package:supper_app/src/services/bus_service/bus_serviec.dart';
import 'package:supper_app/src/services/storage_service/storage_service.dart';
import 'base_module.dart';
import 'services/web_service/dio_base.dart';

abstract class Argument {
  Map<String, dynamic> toMap();
  factory Argument.fromMap(Map<String, dynamic> map) =>
      throw UnimplementedError();
}

class DefaultRoute {
  static Route<dynamic> notFound() => MaterialPageRoute(
      builder: (_) => const Scaffold(
            body: Center(
              child: Text("Page not found !"),
            ),
          ));

  static Widget splashScreen(Widget? screen) {
    if (screen != null) {
      return screen;
    } else {
      return const Scaffold(
        body: Center(
          child: Text("Hello"),
        ),
      );
    }
  }
}

class ModuleManagement {
  static final ModuleManagement _singleton = ModuleManagement._internal();
  final List<BaseModule> _modules = [];
  final seviceLocator = GetIt.instance;

  factory ModuleManagement() {
    return _singleton;
  }

  ModuleManagement._internal();

  void addModules(List<BaseModule> modules) {
    _modules.addAll(modules);
  }

  List<BaseModule> getModules() => _modules;

  static T? arguments<T extends Argument>(RouteSettings settings, String path,
      T Function(Map<String, dynamic> data) fromMap) {
    if (settings.name != null) {
      Uri uri = Uri.parse(settings.name ?? '');
      if (settings.arguments != null) {
        return settings.arguments as T;
      }
      if (uri.pathSegments.isNotEmpty || uri.queryParameters.isNotEmpty) {
        List<String> segments = [...uri.pathSegments];
        if (segments.length % 2 == 1) {
          segments.removeAt(0);
        }
        Map<String, String> result = {};
        for (int a = 0; a < segments.length; a = a + 2) {
          result[segments[a]] = segments[a + 1];
        }
        result = {...result, ...uri.queryParameters};
        T arg1 = fromMap(result);
        return arg1;
      }
    }
    return null;
  }

  Route<dynamic> onGenerateRoute(RouteSettings settings) {
    for (final module in _modules) {
      if ((settings.name ?? "").contains(module.modulePath())) {
        return module.onGenerateRoute(settings);
      }
    }
    return DefaultRoute.notFound();
  }

  List<LocalizationsDelegate> localizationsDelegates() {
    List<LocalizationsDelegate> result = [];
    for (final module in _modules) {
      result.addAll(module.localizationsDelegates());
    }
    return result;
  }

  void injectDependencies() async {
    seviceLocator.registerSingleton(() => StorageService());
    seviceLocator.registerSingleton(() => BusService());
    final dio = await setupDio();
    seviceLocator.registerLazySingleton(() => dio);
    final Alice alice = Alice(
      showNotification: false,
      showInspectorOnShake: false,
    );
    dio.interceptors.add(alice.getDioInterceptor());
    seviceLocator.registerSingleton(alice);

    // final storageService = GetIt.instance<StorageService>();
    // final appTheme = storageService.shared.getString("theme") ?? "";
    // final language = storageService.shared.getString("language") ?? "";

    seviceLocator.registerSingleton(() => AppCubit(
        const AppState(appTheme: AppTheme.light, appLanguage: AppLanguage.vi)));

    for (final module in _modules) {
      module.injectServieces(seviceLocator);
    }
  }
}

==> supper_app-0.0.7.tar.gz: lib/src/module_management.dart <==
// import 'package:alice/alice.dart';
import 'package:alice/alice.dart';
import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:shake/shake.dart';
import 'package:supper_app/src/services/app_service/app_service.dart';
import 'package:supper_app/src/services/bus_service/bus_service.dart';
import 'package:supper_app/src/services/storage_service/storage_service.dart';
import 'package:supper_app/src/services/web_service/config/global_config.dart';
import 'base_module.dart';
import 'services/web_service/dio_base.dart';
import 'package:flutter/foundation.dart';

abstract class Argument {
  Map<String, dynamic> toMap();
  factory Argument.fromMap(Map<String, dynamic> map) =>
      throw UnimplementedError();
}

class DefaultRoute {
  static Route<dynamic> notFound() => MaterialPageRoute(
      builder: (_) => const Scaffold(
            body: Center(
              child: Text("Page not found !"),
            ),
          ));

  static Widget splashScreen(Widget? screen) {
    if (screen != null) {
      return screen;
    } else {
      return const Scaffold(
        body: Center(
          child: Text("Hello"),
        ),
      );
    }
  }
}

class ModuleManagement {
  static final ModuleManagement _singleton = ModuleManagement._internal();
  final List<BaseModule> _modules = [];
  final serviceLocator = GetIt.instance;

  factory ModuleManagement() {
    return _singleton;
  }

  ModuleManagement._internal();

  void addModules(List<BaseModule> modules) {
    _modules.addAll(modules);
  }

  List<BaseModule> getModules() => _modules;

  static T? arguments<T extends Argument>(RouteSettings settings, String path,
      T Function(Map<String, dynamic> data) fromMap) {
    if (settings.name != null) {
      Uri uri = Uri.parse(settings.name ?? '');
      if (settings.arguments != null) {
        return settings.arguments as T;
      }
      if (uri.pathSegments.isNotEmpty || uri.queryParameters.isNotEmpty) {
        List<String> segments = [...uri.pathSegments];
        if (segments.length % 2 == 1) {
          segments.removeAt(0);
        }
        Map<String, String> result = {};
        for (int a = 0; a < segments.length; a = a + 2) {
          result[segments[a]] = segments[a + 1];
        }
        result = {...result, ...uri.queryParameters};
        T arg1 = fromMap(result);
        return arg1;
      }
    }
    return null;
  }

  Route<dynamic> onGenerateRoute(RouteSettings settings) {
    for (final module in _modules) {
      if ((settings.name ?? "").contains(module.modulePath())) {
        return module.onGenerateRoute(settings);
      }
    }
    return DefaultRoute.notFound();
  }

  List<LocalizationsDelegate> localizationsDelegates() {
    List<LocalizationsDelegate> result = [];
    for (final module in _modules) {
      result.addAll(module.localizationsDelegates());
    }
    return result;
  }

  void injectDependencies() async {
    serviceLocator.registerSingleton(() => StorageService());
    serviceLocator.registerSingleton(() => BusService());

    // final _configPath = 'assets/cfg/dev_env.json';
    // GlobalConfiguration globalConfig;
    // globalConfig = await GlobalConfiguration.setup(_configPath);

    // GetIt.I.registerLazySingleton<GlobalConfiguration>(() => globalConfig);

    final dio = await setupDio();
    serviceLocator.registerLazySingleton(() => dio);
    final Alice alice = Alice(
      showNotification: false,
      showInspectorOnShake: false,
    );
    dio.interceptors.add(alice.getDioInterceptor());
    serviceLocator.registerSingleton(alice);

    // final storageService = GetIt.instance<StorageService>();
    // final appTheme = storageService.shared.getString("theme") ?? "";
    // final language = storageService.shared.getString("language") ?? "";

    serviceLocator.registerSingleton(() => AppCubit(
        const AppState(appTheme: AppTheme.light, appLanguage: AppLanguage.vi)));

    for (final module in _modules) {
      module.injectServices(serviceLocator);
    }
  }
}
